### To be ported to 1.3 framework.
#
#
use LedgerSMB::Project;
use LedgerSMB::Template;
sub get_inv_report {
    my $template = LedgerSMB::Template->new(
        user     => \%myconfig,
        locale   => $locale,
        path     => 'UI',
        template => 'form-dynatable',
        format   => ($form->{format}) ? $form->{format} : 'HTML',
        output_file => ($form->{format}) ? "$$.$form->{format}" : undef,
    );

    my $project = LedgerSMB::Project->new({base => $form});
    $project->get_by_id($form->{project_id});
    my @results = $project->get_invoice_report();
    my $cols; 
    @$cols = qw(ord_type name invnumber partnumber partdesc qty sellprice 
               total);
    my $header = { ord_type       => $locale->text('Type'), 
                   name         => $locale->text('Customer/Vendor'),
                   invnummber => $locale->text('Reference'),
                   partnumber => $locale->text('Partnumber'),
                   partdesc   => $locale->text('Description'),
                   sellprice  => $locale->text('Sell Price'),
                   qty        => $locale->text('Qty'),
                   total      => $locale->text('Total'),
                 };
    my $rows = [];
    my $count = 0;
    my $subtotal = Math::BigFloat->bzero();
    my $last_type;
    my $last_inv;
    for my $row (@{$project->{inv_report_lines}}){
        if (!$last_type){
            $last_type = $row->{ord_type};
            $last_inv = $row->{trans_id};
        }
        my $href_args="login=$form->{login}&type=$row->{ord_type}";
        my $href_script;
        if ($row->{ord_type} eq 'ap') {
            $href_script = 'ir.pl';
        } elsif ($row->{ord_type} eq 'ar'){
            $href_script = 'is.pl';
        } else {
            $href_script = 'oe.pl';
            
        }
        if (($row->{ord_type} ne $last_type) 
             or ($row->{trans_id} ne $last_inv)){
           push @$rows, {total => $subtotal->bstr(), class => 'subtotal'};
           $subtotal = Math::BigFloat->bzero();
            $last_type = $row->{ord_type};
            $last_inv = $row->{trans_id};
        }
        $row->{total} = $row->{sellprice} * $row->{qty}->bstr();
        $subtotal += $row->{total};
        $row->{total} = $row->{total}->bstr();
        $row->{i} = $count % 2;
        $row->{sellprice} = $row->{sellprice}->bstr();
        $row->{qty} = $row->{qty}->bstr();
        $row->{invnumber} = {
                text => $row->{invnumber},
                href => "$href_script?action=edit&id=$row->{trans_id}&$href_args",
        };
        push @$rows, $row;
        ++$count;
    }
    push @$rows, {total => $subtotal->bstr(), class => 'subtotal'};
    $form->{title} = $locale->text("Project Invoice/Order Report:") .
             $project->{projectnumber} . ', ' . $project->{description};
    $template->render({
        form    => $form,
        columns => $cols,
        heading => $header,
        rows    => $rows,
        buttons => [{text  => $locale->text('OpenOffice Calc'),
                    value => 'inv_report_oocalc',
                    type  => 'submit',
                    name  => 'action'
                   }],
       hiddens  => {login => $form->{login}},
                    
    });
}

sub inv_report_oocalc {
    $form->{format} = 'CSV';
    get_inv_report();
}

sub inv_report_filter {
    $form->all_projects(\%myconfig, undef, $form->{transdate});
    for my $p (@{$form->{all_project}}){
        $p->{text} = "$p->{projectnumber}--$p->{description}";
    }
    my $template = LedgerSMB::Template->new(
        user     => \%myconfig,
        locale   => $locale,
        path     => 'UI',
        template => 'project_report_filter',
        format   => 'HTML',
    );
    $template->render($form);
}

1;
